@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.3.1
+#www2sms.py v1.3.2
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ from PyQt4.QtGui import QMainWindow, QDialog, QPushButton, QMessageBox, QPixmap
 from www2sms_gui_main import Ui_MainWindow
 from www2sms_gui_widget_account import Ui_FormAccount
 from www2sms_gui_dialog_progress import Ui_Form_Progress
-__version__ = '1.3.1'
+__version__ = '1.3.2'
 __version_info__ = tuple([ int(num) for num in __version__.split('.')])
 
 USER = pwd.getpwuid(os.getuid())[0]
@@ -461,12 +461,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			QMessageBox.warning(self, 'www2sms', message)
 			return
 		if FIXED_NUMBER != NUMBER:
-		    	reply = QMessageBox.question(self, 'www2sms', "Correct number?\n%s --> %s" %(NUMBER, FIXED_NUMBER), QMessageBox.Yes, QMessageBox.No)
-		    	if reply == QMessageBox.Yes:
-			    	NUMBER = FIXED_NUMBER
-				self.ui.lineEdit_Number.setText(NUMBER)
-			else:
-				return
+			NUMBER = FIXED_NUMBER
+			self.ui.lineEdit_Number.setText(NUMBER)
 		# Check if there is some text to send at all
 		# Read the text we want to send
 		self.SMSTEXT = unicode(self.ui.plainTextEdit_SMS.toPlainText())
@@ -475,30 +471,25 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			return
 		self.ui.pushButton_Send.setText("Sending...")
 		self.ui.pushButton_Send.setEnabled(False)
-		# Really ready to send?
-		reply = QMessageBox.question(self, 'Send SMS?', "Are you sure?", QMessageBox.Yes, QMessageBox.No)
-		# If reply is YES, we send the SMS, else we just do nothing
-		if reply == QMessageBox.Yes:
-			self.Stat = FormPro()
-			# Read the login
-			LOGIN = unicode(self.AccSet.ui.lineEdit_SetupLogin.text())
-			# Read the password
-			PASSWORD = unicode(self.AccSet.ui.lineEdit_SetupPassword.text())
-			# Read the ALIAS
-			ALIAS = unicode(self.AccSet.ui.lineEdit_SetupNewAlias.text())
-			# send the SMS
-			STATUS, MSG = provider.sendSMS(self, app, NUMBER, self.SMSTEXT, LOGIN, PASSWORD)
-			self.Stat.close()
-			if STATUS == True:
-				self.on_send_success(MSG, ORGNUM)
-			else:
-				self.on_send_failed(MSG, ORGNUM)
+		self.Stat = FormPro()
+		# Read the login
+		LOGIN = unicode(self.AccSet.ui.lineEdit_SetupLogin.text())
+		# Read the password
+		PASSWORD = unicode(self.AccSet.ui.lineEdit_SetupPassword.text())
+		# Read the ALIAS
+		ALIAS = unicode(self.AccSet.ui.lineEdit_SetupNewAlias.text())
+		# send the SMS
+		STATUS, MSG = provider.sendSMS(self, app, NUMBER, self.SMSTEXT, LOGIN, PASSWORD)
+		self.Stat.close()
+		if STATUS == True:
+			self.on_send_success(MSG, ORGNUM)
+		else:
+			self.on_send_failed(MSG, ORGNUM)
 		self.ui.pushButton_Send.setEnabled(True)
 		self.ui.pushButton_Send.setText("Send")
 
 	# Method which is called from providers class when the sms was successfully send
 	def on_send_success(self,MSG,NUM):
-		QMessageBox.information(self, 'www2sms', MSG)
 		#self.ui.lineEdit_Number.clear()
 		self.ui.plainTextEdit_SMS.clear()
 		# grp is last 7 (or fewer) digits/whatever
